@@ -1,4 +1,4 @@
-# $Id: Daemon.pm,v 1.22 2001/01/04 21:43:10 gisle Exp $
+# $Id: Daemon.pm,v 1.25 2001/08/07 19:32:40 gisle Exp $
 #
 
 use strict;
@@ -14,7 +14,7 @@ HTTP::Daemon - a simple http server class
   use HTTP::Daemon;
   use HTTP::Status;
 
-  my $d = new HTTP::Daemon;
+  my $d = HTTP::Daemon->new || die;
   print "Please contact me at: <URL:", $d->url, ">\n";
   while (my $c = $d->accept) {
       while (my $r = $c->get_request) {
@@ -37,10 +37,14 @@ sub-class of I<IO::Socket::INET>, so you can perform socket operations
 directly on it too.
 
 The accept() method will return when a connection from a client is
-available. The returned value will be a reference to a object of the
-I<HTTP::Daemon::ClientConn> class which is another I<IO::Socket::INET>
-subclass. Calling the get_request() method on this object will read
-data from the client and return an I<HTTP::Request> object reference.
+available.  In a scalar context the returned value will be a reference
+to a object of the I<HTTP::Daemon::ClientConn> class which is another
+I<IO::Socket::INET> subclass.  In a list context a two-element array
+is returned containing the new I<HTTP::Daemon::ClientConn> reference
+and the peer address; the list will be empty upon failure.  Calling
+the get_request() method on the I<HTTP::Daemon::ClientConn> object
+will read data from the client and return an I<HTTP::Request> object
+reference.
 
 This HTTP daemon does not fork(2) for you.  Your application, i.e. the
 user of the I<HTTP::Daemon> is reponsible for forking if that is
@@ -60,9 +64,9 @@ to the I<IO::Socket::INET> base class.
 
 use vars qw($VERSION @ISA $PROTO $DEBUG);
 
-$VERSION = sprintf("%d.%02d", q$Revision: 1.22 $ =~ /(\d+)\.(\d+)/);
+$VERSION = sprintf("%d.%02d", q$Revision: 1.25 $ =~ /(\d+)\.(\d+)/);
 
-use IO::Socket ();
+use IO::Socket qw(AF_INET INADDR_ANY inet_ntoa);
 @ISA=qw(IO::Socket::INET);
 
 $PROTO = "HTTP/1.1";
@@ -87,25 +91,21 @@ sub new
     my($class, %args) = @_;
     $args{Listen} ||= 5;
     $args{Proto}  ||= 'tcp';
-    my $self = $class->SUPER::new(%args);
-    return undef unless $self;
-
-    my $host = $args{LocalAddr};
-    unless ($host) {
-	require Sys::Hostname;
-	$host = lc Sys::Hostname::hostname();
-    }
-    ${*$self}{'httpd_server_name'} = $host;
-    $self;
+    return $class->SUPER::new(%args);
 }
 
 
 =item $c = $d->accept([$pkg])
 
 This method is the same as I<IO::Socket::accept> but returns an
-I<HTTP::Daemon::ClientConn> reference by default.  It returns
-undef if you specify a timeout and no connection is made within
-that time.
+I<HTTP::Daemon::ClientConn> reference by default.  It returns undef if
+you specify a timeout and no connection is made within that time.  In
+a scalar context the returned value will be a reference to a object of
+the I<HTTP::Daemon::ClientConn> class which is another
+I<IO::Socket::INET> subclass.  In a list context a two-element array
+is returned containing the new I<HTTP::Daemon::ClientConn> reference
+and the peer address; the list will be empty upon failure.
+
 
 =cut
 
@@ -113,9 +113,13 @@ sub accept
 {
     my $self = shift;
     my $pkg = shift || "HTTP::Daemon::ClientConn";
-    my $sock = $self->SUPER::accept($pkg);
-    ${*$sock}{'httpd_daemon'} = $self if $sock;
-    $sock;
+    my ($sock, $peer) = $self->SUPER::accept($pkg);
+    if ($sock) {
+        ${*$sock}{'httpd_daemon'} = $self;
+        return wantarray ? ($sock, $peer) : $sock;
+    } else {
+        return;
+    }
 }
 
 
@@ -129,7 +133,14 @@ sub url
 {
     my $self = shift;
     my $url = "http://";
-    $url .= ${*$self}{'httpd_server_name'};
+    my $addr = $self->sockaddr;
+    if ($addr eq INADDR_ANY) {
+ 	require Sys::Hostname;
+ 	$url .= lc Sys::Hostname::hostname();
+    }
+    else {
+	$url .= gethostbyaddr($addr, AF_INET) || inet_ntoa($addr);
+    }
     my $port = $self->sockport;
     $url .= ":$port" if $port != 80;
     $url .= "/";
@@ -216,7 +227,7 @@ sub get_request
     $self->reason("");
     my $buf = ${*$self}{'httpd_rbuf'};
     $buf = "" unless defined $buf;
-    
+
     my $timeout = $ {*$self}{'io_socket_timeout'};
     my $fdset = "";
     vec($fdset, $self->fileno, 1) = 1;
@@ -252,8 +263,12 @@ sub get_request
 	$self->reason("Bad request line: $buf");
 	return;
     }
+    my $method = $1;
+    my $uri = $2;
     my $proto = $3 || "HTTP/0.9";
-    my $r = HTTP::Request->new($1, $HTTP::URI_CLASS->new($2, $self->daemon->url));
+    $uri = "http://$uri" if $method eq "CONNECT";
+    $uri = $HTTP::URI_CLASS->new($uri, $self->daemon->url);
+    my $r = HTTP::Request->new($method, $uri);
     $r->protocol($proto);
     ${*$self}{'httpd_client_proto'} = $proto = _http_version($proto);
 
@@ -792,11 +807,11 @@ sub daemon
 
 RFC 2068
 
-L<IO::Socket>, L<Apache>
+L<IO::Socket::INET>, L<Apache>
 
 =head1 COPYRIGHT
 
-Copyright 1996-1998, Gisle Aas
+Copyright 1996-2001, Gisle Aas
 
 This library is free software; you can redistribute it and/or
 modify it under the same terms as Perl itself.
