@@ -1,9 +1,9 @@
 #
-# $Id: LWP.pm,v 1.98 2001/03/29 21:32:11 gisle Exp $
+# $Id: LWP.pm,v 1.112 2001/10/26 23:24:03 gisle Exp $
 
 package LWP;
 
-$VERSION = "5.52";
+$VERSION = "5.60";
 sub Version { $VERSION; }
 
 require 5.004;
@@ -402,7 +402,8 @@ encoded in the URL.  Failed logins return an UNAUTHORIZED response with
 for HTTP.
 
 The library supports ftp ASCII transfer mode by specifying the "type=a"
-parameter in the URL.
+parameter in the URL. It also supports transfer of ranges for FTP transfers
+using the "Range" header.
 
 Directory listings are by default returned unprocessed (as returned
 from the ftp server) with the content media type reported to be
@@ -492,7 +493,7 @@ The "To" header is initialized from the mail address in the URL.
 
 Example:
 
-  $req = HTTP::Request->new(POST => 'mailto:libwww@perl.ord');
+  $req = HTTP::Request->new(POST => 'mailto:libwww@perl.org');
   $req->header(Subject => "subscribe");
   $req->content("Please subscribe me to the libwww-perl mailing list!\n");
 
